<?php
class cmsCache {

    private static $instance;

    private $cacher;
    private $cache_ttl;
    private $is_debug = false;

    public $query_count = 0;

    public static function getInstance() {
        if (self::$instance === null) {
            self::$instance = new self;
        }
        return self::$instance;
    }

    public function __construct() {

        $config = cmsConfig::getInstance();

        if ($config->cache_enabled) {

            $cacher_class = 'cmsCache' . string_to_camel('_', $config->cache_method);

            $this->cacher = new $cacher_class();

            $this->cache_ttl = $config->cache_ttl;
            $this->is_debug  = $config->debug;

        }

    }

    public function __call($method_name, $arguments) {

        // кеширование отключено
        if(!isset($this->cacher)){
            return false;
        }
        // есть метод здесь, вызываем его
        if(method_exists($this, '_'.$method_name)){
            return call_user_func_array(array($this, '_'.$method_name), $arguments);
        }
        // есть метод в кешере, вызываем его
        if(method_exists($this->cacher, $method_name)){
            return call_user_func_array(array($this->cacher, $method_name), $arguments);
        }
        // ничего нет
        trigger_error('not defined method name '.$method_name, E_USER_NOTICE);
        return false;

    }

    private function _set($key, $value, $ttl=false){

        // >> <WebMan> - debug
        if (!$ttl) { $ttl = $this->cache_ttl; }

        if (DEBUG_ON) {
          $debug = cmsDebug::getInstance();
          $debug->beginCache();
        }
        $ret = $this->cacher->set($key, $value, $ttl);
        if (DEBUG_ON) { $debug->endCache('set', $key, $ret, $value); }
        
        return $ret;
        // << </WebMan> - debug

    }

    private function _get($key){

        // >> <WebMan> - debug
        if (DEBUG_ON) {
          $debug = cmsDebug::getInstance();
          $debug->beginCache();
        }

        if (!$this->cacher->has($key)) {
          if (DEBUG_ON) { $debug->endCache('get', $key, false, 'Not found in a cache'); }
          return false;
        }
        
        $value = $this->cacher->get($key);
        
        if (DEBUG_ON) { $debug->endCache('get', $key, true, $value); }
        // << </WebMan> - debug

        if ($this->is_debug && $value) {
            $this->query_count++;
        }

        return $value;

    }

}